Struct sysctl::CtlInfo[][src]

pub struct CtlInfo {
    pub ctl_type: CtlType,
    pub fmt: String,
    // some fields omitted
}

A structure representing control metadata

Fields

The control type.

A string which specifies the format of the OID in a symbolic way.

This format is used as a hint by sysctl(8) to apply proper data formatting for display purposes.

Formats defined in sysctl(9):

Methods

impl CtlInfo
[src]

Return the flags for this sysctl.

Is this sysctl a temperature?

If the sysctl is a structure, return the structure type string.

Checks whether the format string starts with S, and returns the rest of the format string or None if the format String does not have a struct hint.