[−]Struct sysctl::CtlFlags
Methods
impl CtlFlags
pub const RD: CtlFlags
Allow reads of variable
pub const WR: CtlFlags
Allow writes to the variable
pub const RW: CtlFlags
pub const DORMANT: CtlFlags
This sysctl is not active yet
pub const ANYBODY: CtlFlags
All users can set this var
pub const SECURE: CtlFlags
Permit set only if securelevel<=0
pub const PRISON: CtlFlags
Prisoned roots can fiddle
pub const DYN: CtlFlags
Dynamic oid - can be freed
pub const SKIP: CtlFlags
Skip this sysctl when listing
pub const SECURE_MASK: CtlFlags
Secure level
pub const TUN: CtlFlags
Default value is loaded from getenv()
pub const RDTUN: CtlFlags
Readable tunable
pub const RWTUN: CtlFlags
Readable and writeable tunable
pub const MPSAFE: CtlFlags
Handler is MP safe
pub const VNET: CtlFlags
Prisons with vnet can fiddle
pub const DYING: CtlFlags
Oid is being removed
pub const CAPRD: CtlFlags
Can be read in capability mode
pub const CAPWR: CtlFlags
Can be written in capability mode
pub const STATS: CtlFlags
Statistics; not a tuneable
pub const NOFETCH: CtlFlags
Don't fetch tunable from getenv()
pub const CAPRW: CtlFlags
Can be read and written in capability mode
pub fn empty() -> CtlFlags
Returns an empty set of flags.
pub fn all() -> CtlFlags
Returns the set containing all flags.
pub fn bits(&self) -> c_uint
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: c_uint) -> Option<CtlFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_uint) -> CtlFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
pub fn is_all(&self) -> bool
Returns true if all flags are currently set.
pub fn intersects(&self, other: CtlFlags) -> bool
Returns true if there are flags common to both self and other.
pub fn contains(&self, other: CtlFlags) -> bool
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: CtlFlags)
Inserts the specified flags in-place.
pub fn remove(&mut self, other: CtlFlags)
Removes the specified flags in-place.
pub fn toggle(&mut self, other: CtlFlags)
Toggles the specified flags in-place.
pub fn set(&mut self, other: CtlFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.