Struct sysctl::CtlFlags[]

pub struct CtlFlags { /* fields omitted */ }

Methods

impl CtlFlags

RD: CtlFlags = CtlFlags{bits: CTLFLAG_RD,}

Allow reads of variable

WR: CtlFlags = CtlFlags{bits: CTLFLAG_WR,}

Allow writes to the variable

RW: CtlFlags = CtlFlags{bits: <Self>::RD.bits | <Self>::WR.bits,}

DORMANT: CtlFlags = CtlFlags{bits: CTLFLAG_DORMANT,}

This sysctl is not active yet

ANYBODY: CtlFlags = CtlFlags{bits: CTLFLAG_ANYBODY,}

All users can set this var

SECURE: CtlFlags = CtlFlags{bits: CTLFLAG_SECURE,}

Permit set only if securelevel<=0

PRISON: CtlFlags = CtlFlags{bits: CTLFLAG_PRISON,}

Prisoned roots can fiddle

DYN: CtlFlags = CtlFlags{bits: CTLFLAG_DYN,}

Dynamic oid - can be freed

SKIP: CtlFlags = CtlFlags{bits: CTLFLAG_DORMANT,}

Skip this sysctl when listing

SECURE_MASK: CtlFlags = CtlFlags{bits: 15728640,}

Secure level

TUN: CtlFlags = CtlFlags{bits: CTLFLAG_TUN,}

Default value is loaded from getenv()

RDTUN: CtlFlags = CtlFlags{bits: <Self>::RD.bits | <Self>::TUN.bits,}

Readable tunable

RWTUN: CtlFlags = CtlFlags{bits: <Self>::RW.bits | <Self>::TUN.bits,}

Readable and writeable tunable

MPSAFE: CtlFlags = CtlFlags{bits: CTLFLAG_MPSAFE,}

Handler is MP safe

VNET: CtlFlags = CtlFlags{bits: CTLFLAG_VNET,}

Prisons with vnet can fiddle

DYING: CtlFlags = CtlFlags{bits: CTLFLAG_DYING,}

Oid is being removed

CAPRD: CtlFlags = CtlFlags{bits: CTLFLAG_CAPRD,}

Can be read in capability mode

CAPWR: CtlFlags = CtlFlags{bits: CTLFLAG_CAPWR,}

Can be written in capability mode

STATS: CtlFlags = CtlFlags{bits: CTLFLAG_STATS,}

Statistics; not a tuneable

NOFETCH: CtlFlags = CtlFlags{bits: CTLFLAG_NOFETCH,}

Don't fetch tunable from getenv()

CAPRW: CtlFlags = CtlFlags{bits: <Self>::CAPRD.bits | <Self>::CAPWR.bits,}

Can be read and written in capability mode

Returns an empty set of flags.

Returns the set containing all flags.

Returns the raw value of the flags currently stored.

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

Returns true if no flags are currently stored.

Returns true if all flags are currently set.

Returns true if there are flags common to both self and other.

Returns true all of the flags in other are contained within self.

Inserts the specified flags in-place.

Removes the specified flags in-place.

Toggles the specified flags in-place.

Inserts or removes the specified flags depending on the passed value.