Struct sysctl::CtlFlags
[−]
pub struct CtlFlags { /* fields omitted */ }
Methods
impl CtlFlags
pub const RD: CtlFlags
RD: CtlFlags = CtlFlags{bits: CTLFLAG_RD,}
Allow reads of variable
pub const WR: CtlFlags
WR: CtlFlags = CtlFlags{bits: CTLFLAG_WR,}
Allow writes to the variable
pub const RW: CtlFlags
RW: CtlFlags = CtlFlags{bits: <Self>::RD.bits | <Self>::WR.bits,}
pub const DORMANT: CtlFlags
DORMANT: CtlFlags = CtlFlags{bits: CTLFLAG_DORMANT,}
This sysctl is not active yet
pub const ANYBODY: CtlFlags
ANYBODY: CtlFlags = CtlFlags{bits: CTLFLAG_ANYBODY,}
All users can set this var
pub const SECURE: CtlFlags
SECURE: CtlFlags = CtlFlags{bits: CTLFLAG_SECURE,}
Permit set only if securelevel<=0
pub const PRISON: CtlFlags
PRISON: CtlFlags = CtlFlags{bits: CTLFLAG_PRISON,}
Prisoned roots can fiddle
pub const DYN: CtlFlags
DYN: CtlFlags = CtlFlags{bits: CTLFLAG_DYN,}
Dynamic oid - can be freed
pub const SKIP: CtlFlags
SKIP: CtlFlags = CtlFlags{bits: CTLFLAG_DORMANT,}
Skip this sysctl when listing
pub const SECURE_MASK: CtlFlags
SECURE_MASK: CtlFlags = CtlFlags{bits: 15728640,}
Secure level
pub const TUN: CtlFlags
TUN: CtlFlags = CtlFlags{bits: CTLFLAG_TUN,}
Default value is loaded from getenv()
pub const RDTUN: CtlFlags
RDTUN: CtlFlags = CtlFlags{bits: <Self>::RD.bits | <Self>::TUN.bits,}
Readable tunable
pub const RWTUN: CtlFlags
RWTUN: CtlFlags = CtlFlags{bits: <Self>::RW.bits | <Self>::TUN.bits,}
Readable and writeable tunable
pub const MPSAFE: CtlFlags
MPSAFE: CtlFlags = CtlFlags{bits: CTLFLAG_MPSAFE,}
Handler is MP safe
pub const VNET: CtlFlags
VNET: CtlFlags = CtlFlags{bits: CTLFLAG_VNET,}
Prisons with vnet can fiddle
pub const DYING: CtlFlags
DYING: CtlFlags = CtlFlags{bits: CTLFLAG_DYING,}
Oid is being removed
pub const CAPRD: CtlFlags
CAPRD: CtlFlags = CtlFlags{bits: CTLFLAG_CAPRD,}
Can be read in capability mode
pub const CAPWR: CtlFlags
CAPWR: CtlFlags = CtlFlags{bits: CTLFLAG_CAPWR,}
Can be written in capability mode
pub const STATS: CtlFlags
STATS: CtlFlags = CtlFlags{bits: CTLFLAG_STATS,}
Statistics; not a tuneable
pub const NOFETCH: CtlFlags
NOFETCH: CtlFlags = CtlFlags{bits: CTLFLAG_NOFETCH,}
Don't fetch tunable from getenv()
pub const CAPRW: CtlFlags
CAPRW: CtlFlags = CtlFlags{bits: <Self>::CAPRD.bits | <Self>::CAPWR.bits,}
Can be read and written in capability mode
pub fn empty() -> CtlFlags
Returns an empty set of flags.
pub fn all() -> CtlFlags
Returns the set containing all flags.
pub fn bits(&self) -> c_uint
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: c_uint) -> Option<CtlFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_uint) -> CtlFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
pub fn is_all(&self) -> bool
Returns true if all flags are currently set.
pub fn intersects(&self, other: CtlFlags) -> bool
Returns true if there are flags common to both self and other.
pub fn contains(&self, other: CtlFlags) -> bool
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: CtlFlags)
Inserts the specified flags in-place.
pub fn remove(&mut self, other: CtlFlags)
Removes the specified flags in-place.
pub fn toggle(&mut self, other: CtlFlags)
Toggles the specified flags in-place.
pub fn set(&mut self, other: CtlFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.